@@ -583,7 +583,18 @@ class Plugin(plugin.PluginBase):
             ),
         )
 
-        if self.environment[constants.LDAPEnv.PROFILE] is None:
+        if self.environment[constants.LDAPEnv.PROFILE] is not None:
+            if self.environment[constants.LDAPEnv.PROFILE] not in [
+                e['profile'] for e in self.environment[
+                    constants.LDAPEnv.AVAILABLE_PROFILES
+                ]
+            ]:
+                raise self.SoftRuntimeError(
+                    _("Profile {profile} was not found.").format(
+                        profile=self.environment[constants.LDAPEnv.PROFILE],
+                    )
+                )
+        else:
             profiles = []
             values = {}
             for i, p in enumerate(
@@ -776,7 +787,8 @@ class Plugin(plugin.PluginBase):
                 user = self.dialog.queryString(
                     name='OVAAALDAP_LDAP_USER',
                     note=_(
-                        'Enter search user DN (empty for anonymous): '
+                        'Enter search user DN (for example uid=username,'
+                        'dc=example,dc=com or leave empty for anonymous): '
                     ),
                     prompt=True,
                     default='',
@@ -856,7 +868,7 @@ class Plugin(plugin.PluginBase):
             ] = self.dialog.queryString(
                 name='OVAAALDAP_LDAP_AAA_USE_VM_SSO',
                 note=_(
-                    'Are you going to use Single Sing-On for Virtual Machines'
+                    'Are you going to use Single Sign-On for Virtual Machines'
                     ' (@VALUES@) [@DEFAULT@]: '
                 ),
                 prompt=True,
